"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserGroupBuilder = void 0;
const faker = require("faker");
const camelize = require("camelize");
const permissionsBuilder_1 = require("./permissionsBuilder");
const nodePermissionCollectionBuilder_1 = require("./nodePermissionCollectionBuilder");
class UserGroupBuilder {
    alias;
    icon;
    id;
    name;
    parentId;
    sections;
    startContentId;
    startMediaId;
    users;
    action;
    defaultPermissionsBuilder;
    assignedPermissionsBuilder;
    constructor() {
        this.sections = [];
        this.users = [];
    }
    withAlias(alias) {
        this.alias = alias;
        return this;
    }
    getAlias() {
        return this.alias || 'a' + camelize(this.name);
    }
    addNodePermissions(nodePermissionsBuilder) {
        const builder = nodePermissionsBuilder === null || nodePermissionsBuilder === undefined
            ? new nodePermissionCollectionBuilder_1.NodePermissionCollectionBuilder(this)
            : nodePermissionsBuilder;
        this.assignedPermissionsBuilder = builder;
        return builder;
    }
    addDefaultPermissions(userGroupPermissionsBuilder) {
        const builder = userGroupPermissionsBuilder === null || userGroupPermissionsBuilder === undefined
            ? new permissionsBuilder_1.PermissionsBuilder(this)
            : userGroupPermissionsBuilder;
        this.defaultPermissionsBuilder = builder;
        return builder;
    }
    withIcon(icon) {
        this.icon = icon;
        return this;
    }
    withId(id) {
        this.id = id;
        return this;
    }
    withName(name) {
        this.name = name;
        return this;
    }
    withParentId(parentId) {
        this.parentId = parentId;
        return this;
    }
    withSections(sections) {
        this.sections = sections;
        return this;
    }
    appendSections(sections) {
        sections.forEach((section) => { this.sections.push(section); });
        return this;
    }
    appendSection(section) {
        this.sections.push(section);
        return this;
    }
    withContentStartNode(contentStartNodeId) {
        this.startContentId = contentStartNodeId;
        return this;
    }
    withMediaStartNode(mediaStartNodeId) {
        this.startMediaId = mediaStartNodeId;
        return this;
    }
    withUsers(users) {
        this.users = users;
        return this;
    }
    appendUsers(users) {
        users.forEach((userId) => { this.users.push(userId); });
        return this;
    }
    appendUser(user) {
        this.users.push(user);
        return this;
    }
    withAction(action) {
        this.action = action;
        return this;
    }
    withSave() {
        this.action = 'save';
        return this;
    }
    withSaveNew() {
        this.action = 'saveNew';
        return this;
    }
    build() {
        if (this.name === undefined) {
            this.withName(faker.random.uuid());
        }
        let defaultPermissions = [];
        if (this.defaultPermissionsBuilder != undefined) {
            defaultPermissions = this.defaultPermissionsBuilder.build();
        }
        let assignedPermissions = {};
        if (this.assignedPermissionsBuilder != undefined) {
            assignedPermissions = this.assignedPermissionsBuilder.build();
        }
        return {
            action: this.action || 'saveNew',
            alias: this.getAlias(),
            assignedPermissions: assignedPermissions,
            defaultPermissions: defaultPermissions,
            icon: this.icon || 'icon-users',
            id: this.id || 0,
            name: this.name,
            parentId: this.parentId || -1,
            sections: this.sections || [],
            startContentId: this.startContentId || null,
            startMediaId: this.startMediaId || null,
            users: this.users || [],
        };
    }
}
exports.UserGroupBuilder = UserGroupBuilder;
//# sourceMappingURL=userGroupBuilder.js.map